bind

Function bind 

pub fn bind<I: ?Sized + 'static>(
    owner: &dyn PortOwner,
    name: PortName<I>,
    iface: Rc<I>,
) -> Result<(), ConnectError>
Bind iface into owner’s port called name. The kind and transaction type are checked by the compiler through PortName<I>; only the presence of the field can fail here.