GetPort

Type Alias GetPort 

pub type GetPort<T> = Port<dyn GetIf<T>>;
A port that takes items out of something it does not own.

Aliased Type

pub struct GetPort<T> { /* private fields */ }

Implementations

Source

impl<T: 'static> GetPort<T>

pub async fn get(&self) -> T

Block until there is an item, then take it out.

pub fn try_get(&self) -> Option<T>

pub fn can_get(&self) -> bool